diff --git a/Scripts/Functions/Help/help_updateNodes.sh b/Scripts/Functions/Help/help_updateNodes.sh
index 71c7520..be94c2f 100755
--- a/Scripts/Functions/Help/help_updateNodes.sh
+++ b/Scripts/Functions/Help/help_updateNodes.sh
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
 # texinfo_updateNodes.sh -- This function updates chapter's nodes
 # definition using the chapter's menu as reference.
 #
 # Copyright (C) 2009, 2010, 2011 The CentOS Artwork SIG
@@ -23,7 +23,7 @@
 # $Id$
 # ----------------------------------------------------------------------
 
-function texinfo_updateNodes {
+function help_updateNodes {
 
     # Retrive nodes' entries from chapter-menu.texinfo file.
     local NODES=$(cat $MANUAL_CHAPTER_DIR/chapter-menu.${MANUAL_EXTENSION} \
@@ -1,6 +1,6 @@
 #!/bin/bash
 #
-# texinfo_updateNodes.sh -- This function updates chapter's nodes
+# help_updateNodes.sh -- This function updates chapter's nodes
 # definition using the chapter's menu as reference.
 #